@@ -221,10 +221,23 @@ from cr.sparse._src.ndarray import (
     arr_l2norm,
     arr_l2norm_sqr,
     arr_vdot,
+    arr_rdot,
+    arr2vec,
 )
 
 from cr.sparse._src.similarity import (
     dist_to_gaussian_sim,
     sqr_dist_to_gaussian_sim,
     eps_neighborhood_sim
-)
\ No newline at end of file
+)
+
+
+# Evaluation Tools
+
+from cr.sparse._src.tools.performance import (
+    RecoveryPerformance
+)
+
+from cr.sparse._src.tools.trials_at_fixed_m_n import (
+    RecoveryTrialsAtFixed_M_N
+)
